clear;
clc;

controlDict;
addpath('./Integrals');
B1 = ones(ncount1,1);
A1 = zeros(ncount1,dof1+dof2+dof4);

% matrix components for face 1 collocation points
fprintf('face 1 np:%d  dof1: %d  dof2:%d  dof4:%d\n',ncount1,dof1,dof2,dof4);
parfor np = 1:ncount1
    fprintf('face 1 collocation point %d\n',np);
    xp = xpf1(np);
    yp = ypf1(np);
    zp = zpf1(np);
    rp = xp*cos(alpha)-zp*sin(alpha);
    xip = xp*sin(alpha)+zp*cos(alpha);
    thp = atan2(yp,rp);
    rp = sqrt(rp*rp+yp*yp);
    % face 1 integral
    Au1 = [];
    for nc = 0:Ncos-1
        Anc = zeros(1,NrU+1);
        for nra = 1:NrU
            rNs = RnodesU(nra:nra+1);
            Anc(nra) = Anc(nra)-G1(alpha,xp,yp,zp,rNs,nc,0,0,ztol);
            Anc(nra+1) = Anc(nra+1)-G1(alpha,xp,yp,zp,rNs,nc,1,0,ztol);            
        end
        Au1 = [Au1 Anc];
    end
    % face 2 integral
    Aphi2 = [];
    for nc = 0:Ncos-1
        Anc = zeros(1,Nxi+1);
        for nxiN = 1:Nxi
            xiNs = xinodes(nxiN:nxiN+1);
            xilim = xiNs;
            if nxiN==1
                xilim(1) = 0;
            elseif nxiN==Nxi
                xilim(2) = L/cos(alpha);
            end
            Anc(nxiN) = Anc(nxiN)-dG1r(alpha,xp,yp,zp,xiNs,xilim,nc,0,rtol,ztol);
            Anc(nxiN+1) = Anc(nxiN+1)-dG1r(alpha,xp,yp,zp,xiNs,xilim,nc,1,rtol,ztol);
        end
        Aphi2 = [Aphi2 Anc];
    end
    % face 3 integral u3 (u1 image)
    Au3 = [];
    for nc = 0:Ncos-1
        Anc = zeros(1,NrU+1);
        for nra = 1:NrU
            rNs = RnodesU(nra:nra+1);
            Anc(nra) = Anc(nra)+(uimag^nc)*G1(alpha,xp,yp,zp,rNs,nc,0,L,ztol);
            Anc(nra+1) = Anc(nra+1)+(uimag^nc)*G1(alpha,xp,yp,zp,rNs,nc,1,L,ztol);
        end
        Au3 = [Au3 Anc];
    end
    % face 3 integral phi3
    Aphi3 = [];
    for nc = 0:Ncos-1
        Anc = zeros(1,Nr+1);
        for nra = 1:Nr
            rNs = Rnodes(nra:nra+1);
            Anc(nra) = Anc(nra)-dG1z(alpha,xp,yp,zp,rNs,nc,0,L,ztol);
            Anc(nra+1) = Anc(nra+1)-dG1z(alpha,xp,yp,zp,rNs,nc,1,L,ztol);
        end
        Aphi3 = [Aphi3 Anc];
    end
    % assemble
    B1(np,:) = B1(np,:)*wf1(np);
    A1(np,:) = [Au1+Au3 Aphi2 Aphi3]*wf1(np);
end
   
save('M1.mat','B1','A1');
