clear;
clc;

controlDict;
addpath('./Integrals');
B3 = zeros(ncount3,1);
A3 = zeros(ncount3,dof1+dof2+dof4);
Be = zeros(ncount3,1);
Ae = zeros(ncount3,dof1+dof2+dof4);

% matrix components for face 3 collocation points
fprintf('face 3 np:%d  dof1: %d  dof2:%d  dof4:%d\n',ncount3,dof1,dof2,dof4);
parfor np = 1:ncount3
    fprintf('face 3 collocation point %d\n',np);
    xp = xpf3(np);
    yp = ypf3(np);
    zp = zpf3(np);
    rp = xp*cos(alpha)-zp*sin(alpha);
    xip = xp*sin(alpha)+zp*cos(alpha);
    thp = atan2(yp,rp);
    rp = sqrt(rp*rp+yp*yp);
    % face 1 integral
    Au1 = [];
    for nc = 0:Ncos-1
        Anc = zeros(1,NrU+1);
        for nra = 1:NrU
            rNs = RnodesU(nra:nra+1);
            Anc(nra) = Anc(nra)+G1(alpha,xp,yp,zp,rNs,nc,0,0,ztol);
            Anc(nra+1) = Anc(nra+1)+G1(alpha,xp,yp,zp,rNs,nc,1,0,ztol);            
        end
        Au1 = [Au1 Anc];
    end
    % face 2 integral
    Aphi2 = [];
    for nc = 0:Ncos-1
        Anc = zeros(1,Nxi+1);
        for nxiN = 1:Nxi
            xiNs = xinodes(nxiN:nxiN+1);
            xilim = xiNs;
            if nxiN==1
                xilim(1) = 0;
            elseif nxiN==Nxi
                xilim(2) = L/cos(alpha);
            end
            Anc(nxiN) = Anc(nxiN)+dG1r(alpha,xp,yp,zp,xiNs,xilim,nc,0,rtol,ztol);
            Anc(nxiN+1) = Anc(nxiN+1)+dG1r(alpha,xp,yp,zp,xiNs,xilim,nc,1,rtol,ztol);
        end
        Aphi2 = [Aphi2 Anc];
    end
    % face 3 integral u3 (u1 image)
    Au3 = [];
    Au3e = [];
    for nc = 0:Ncos-1
        Anc = zeros(1,NrU+1);
        Ance = zeros(1,NrU+1);
        for nra = 1:NrU
            rNs = RnodesU(nra:nra+1);
            Anc(nra) = Anc(nra)-(uimag^nc)*G1(alpha,xp,yp,zp,rNs,nc,0,L,ztol);
            Anc(nra+1) = Anc(nra+1)-(uimag^nc)*G1(alpha,xp,yp,zp,rNs,nc,1,L,ztol);
            temp1 = (uimag^nc)*Ge(alpha,xp,yp,zp,rNs,nc,0,L,ztol);
            temp2 = (uimag^nc)*Ge(alpha,xp,yp,zp,rNs,nc,1,L,ztol);
            Anc(nra) = Anc(nra)-temp1/2;
            Anc(nra+1) = Anc(nra+1)-temp2/2;
            % Ae
            Ance(nra) = Ance(nra)+temp1
            Ance(nra+1) = Ance(nra+1)+temp2;
        end
        Au3 = [Au3 Anc];
        Au3e = [Au3e Ance];
    end
    % face 3 integral phi3
    Aphi3 = [];
    for nc = 0:Ncos-1
        Anc = zeros(1,Nr+1);
        for nra = 1:Nr
            rNs = Rnodes(nra:nra+1);
            Anc(nra) = Anc(nra)+dG1z(alpha,xp,yp,zp,rNs,nc,0,L,ztol);
            Anc(nra+1) = Anc(nra+1)+dG1z(alpha,xp,yp,zp,rNs,nc,1,L,ztol);            
        end
        Aphi3 = [Aphi3 Anc];
    end
    % assemble A3
    A3(np,:) = [Au1+Au3 Aphi2 Aphi3]*wf3(np);
    
    % Ae and Be
    Aphi2 = zeros(1,dof2);
    % face 3 interpolation phi3
    Aphi3 = [];
    for nc = 0:Ncos-1
        Anc = zeros(1,Nr+1);
        for nra = 1:Nr
            rNs = Rnodes(nra:nra+1);
            if abs(rp-rNs(1))<rtol
                ctmp = (rp^nc)*cos(nc*thp);
                Anc(nra) = Anc(nra)+ctmp;
            elseif rp-rNs(1)>rtol && rNs(2)-rp>rtol
                ctmp = (rNs(2)^2-rp^2)/(rNs(2)^2-rNs(1)^2)*(rp^nc)*cos(nc*thp);
                Anc(nra) = Anc(nra)+ctmp;
                ctmp = (rp^2-rNs(1)^2)/(rNs(2)^2-rNs(1)^2)*(rp^nc)*cos(nc*thp);
                Anc(nra+1) = Anc(nra+1)+ctmp;
            end
        end
        Aphi3 = [Aphi3 Anc];
    end
    % assemble Ae
    Ae(np,:) = [Au3e Aphi2 Aphi3]*wf3(np);
end
   
save('M3.mat','B3','A3','Be','Ae');
