% impose velocity symmetry
% separate DOF of u1 and phi3
% avoid edge nodes on surface 2
% match edge element size of face2 and face 1 

clear;
clc;

alpha = deg2rad(30);    % inclined angle
hP = 2;                 % plate thickness length
Ncos = 4;               % number of azimuthal modes
aP = 6;                 % major axis spacing
bP = 3;                 % minor axis spacing
Eratio = 2;             % edge element expansion ratio
Npar = 6;               % parallel partitions 

L = hP;                  
xiL = L/cos(alpha)-2*tan(alpha);   

NrU = Ncos+4;
Nr = Ncos+4;
Nth = Ncos*2;
Nrad = Nr*2;
dxiR = 1;

polymesh;
ncount1 = size(xpf1,2);
ncount2 = size(xpf2,2);
ncount3 = size(xpf3,2);
dof1 = Ncos*(NrU+1);    % u1  
dof2 = Ncos*(Nxi+1);    % phi2
dof4 = Ncos*(Nr+1);     % phi3

% tolerance parameters
rtol = 1e-8;
ztol = 1e-8;

uimag = -1;

% eigenexpansion
Rsize = length(Rnodes);
dRx = (Rnodes(Rsize)-Rnodes(Rsize-1))/cos(alpha);
dRy = Rnodes(Rsize)-Rnodes(Rsize-1);
Nx = round(aP*2*Eratio/dRx);
My = round(bP*2*Eratio/dRy);

% parallel partitions
dNxpar = round(Nx/Npar);
Nxpar = [1 dNxpar];
for nNxP=1:Npar-1
    if nNxP<Npar-1
        tempN = [Nxpar(nNxP,2)+1 Nxpar(nNxP,2)+dNxpar];
        Nxpar = [Nxpar; tempN];
    else
        tempN = [Nxpar(nNxP,2)+1 Nx];
        Nxpar = [Nxpar; tempN];
    end
end
